( cd usr/lib ; rm -rf libgal-a11y-2.2.so.0 )
( cd usr/lib ; ln -sf libgal-a11y-2.2.so.0.0.1 libgal-a11y-2.2.so.0 )
( cd usr/lib ; rm -rf libgal-a11y-2.2.so )
( cd usr/lib ; ln -sf libgal-a11y-2.2.so.0.0.1 libgal-a11y-2.2.so )
( cd usr/lib ; rm -rf libgal-2.2.so.0 )
( cd usr/lib ; ln -sf libgal-2.2.so.0.0.1 libgal-2.2.so.0 )
( cd usr/lib ; rm -rf libgal-2.2.so )
( cd usr/lib ; ln -sf libgal-2.2.so.0.0.1 libgal-2.2.so )
